==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/src/x11/lang.cpp <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#include <WScom.h>
#include <WSClocaleSet.h>
#include <WSCinitializeManager.h>

void _libwsx11_lang_init_proc(){
#ifndef NO_ENGLISH_MSG
#include "English.cpp"
#endif
#ifndef NO_JAPANESE_EUC_MSG
#include "Japanese.cpp"
#endif
#ifndef NO_JAPANESE_SJIS_MSG
#include "Japanese-sjis.cpp"
#endif
#ifndef NO_JAPANESE_UTF8_MSG
#include "Japanese-utf8.cpp"
#endif
#ifndef NO_KSC5601_MSG
#include "Korean.cpp"
#endif
#ifndef NO_GB2312_MSG
#include "Chinese-zh_cn.cpp"
#endif
#ifndef NO_ES_MSG
#include "Espanol.cpp"
#endif
}

class _libwsx11_lang_init_{
public:
  _libwsx11_lang_init_(){
    WSGIappInitializeManager()->addInitializeProc(_libwsx11_lang_init_proc);
  };
};

static _libwsx11_lang_init_ _run_libwsx11_lang_init;

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/src/x11/lang.cpp <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

#include <WScom.h>
#include <WSClocaleSet.h>
#include <WSCinitializeManager.h>

void _libwsx11_lang_init_proc(){
#ifndef NO_ENGLISH_MSG
#include "English.cpp"
#endif
#ifndef NO_JAPANESE_EUC_MSG
#include "Japanese.cpp"
#endif
#ifndef NO_JAPANESE_SJIS_MSG
#include "Japanese-sjis.cpp"
#endif
#ifndef NO_JAPANESE_UTF8_MSG
#include "Japanese-utf8.cpp"
#endif
#ifndef NO_KSC5601_MSG
#include "Korean.cpp"
#endif
#ifndef NO_GB2312_MSG
#include "Chinese-zh_cn.cpp"
#endif
#ifndef NO_ES_MSG
#include "Espanol.cpp"
#include "Espanol-ar.cpp"
#endif
#ifndef NO_ES_UTF8_MSG
#include "Espanol-utf8.cpp"
#include "Espanol-ar-utf8.cpp"
#endif
}

class _libwsx11_lang_init_{
public:
  _libwsx11_lang_init_(){
    WSGIappInitializeManager()->addInitializeProc(_libwsx11_lang_init_proc);
  };
};

static _libwsx11_lang_init_ _run_libwsx11_lang_init;
